"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.logResponse = logResponse;
exports.register = register;
Object.defineProperty(exports, "logger", {
  enumerable: true,
  get: function get() {
    return _logger.default;
  }
});
Object.defineProperty(exports, "serializers", {
  enumerable: true,
  get: function get() {
    return _logger.httpRequestSerializers;
  }
});
Object.defineProperty(exports, "MetricLogging", {
  enumerable: true,
  get: function get() {
    return _logger.MetricLogging;
  }
});

var _logger = _interopRequireWildcard(require("./logger"));

function logResponse(request) {
  var response = request.response,
      route = request.route,
      id = request.id,
      logger = request.server.app.logger;

  if (!response) {
    // client hung up
    logger.info({
      httpRequest: request,
      id: id
    });
    return;
  }

  if (response.isBoom) {
    // response is an Error object
    logger.error({
      err: response,
      context: request
    });
  }

  var routePluginSettings = route.settings.plugins['mwp-logger-plugin'];

  if (routePluginSettings && !routePluginSettings.enabled) {
    // short circuit the normal logs for routes that opt-out
    return;
  }

  var log = (response.statusCode >= 500 && logger.error || response.statusCode >= 400 && logger.warn || logger.info).bind(logger);
  log({
    httpRequest: request,
    id: id
  });
  return;
} // this might be redundant with the `logResponse` behavior


var onRequestError = function onRequestError(request, event, tags) {
  if (!tags.error) {
    return;
  }

  var err = event.error && event.error.message ? event.error.message : 'unknown error';

  _logger.default.error({
    err: "Request ".concat(event.request, " failed: ").concat(err),
    context: request,
    error: event.error
  });
};

function register(server, options) {
  server.events.on({
    name: 'request',
    channels: 'error'
  }, onRequestError);
  server.events.on('response', logResponse);
  server.app.logger = _logger.default;
}

// named export for easy import
exports.plugin = {
  register: register,
  name: 'mwp-logger-plugin',
  version: '1.0.0'
};
//# sourceMappingURL=index.js.map